@@ -41,18 +41,15 @@ logger = logging.getLogger(__name__)
 
 @click.group()
 @click.version_option(version=__version__)
-@click.option('--name', '-n', default='reV', type=STR,
-              help='Job name. Default is "reV".')
 @click.option('--config_file', '-c',
               required=True, type=click.Path(exists=True),
               help='reV configuration file json for a single module.')
 @click.option('-v', '--verbose', is_flag=True,
               help='Flag to turn on debug logging. Default is not verbose.')
 @click.pass_context
-def main(ctx, name, config_file, verbose):
+def main(ctx, config_file, verbose):
     """reV command line interface."""
     ctx.ensure_object(dict)
-    ctx.obj['NAME'] = name
     ctx.obj['CONFIG_FILE'] = config_file
     ctx.obj['VERBOSE'] = verbose
 
